@@ -18,9 +18,9 @@
 import math
 import logging
 
-from PySide2.QtCore import *
-from PySide2.QtGui import *
-from PySide2.QtWidgets import *
+from PySide6.QtCore import *
+from PySide6.QtGui import *
+from PySide6.QtWidgets import *
 from . import ogParser
 from .TextInteraction import EditableText
 
@@ -36,30 +36,41 @@ class Connection(QGraphicsPathItem):
 
     def __init__(self, parent, child):
         ''' Create a new connection between a parent and a child item '''
-        super(Connection, self).__init__(parent)
+        super().__init__(parent)
         self.parent = parent
         self.child = child
         self._start_point = None
         self._end_point = None
         self._middle_points = []
-        pen = QPen()
-        pen.setColor(Qt.blue)
-        pen.setCosmetic(False)
-        self.setPen(pen)
+        self.default_pen = QPen()
+        self.default_pen.setColor(Qt.blue)
+        self.default_pen.setCosmetic(False)
+        self.setPen(self.default_pen)
+        self.bold_pen = QPen()
+        self.bold_pen.setWidth(3)
         self.parent_rect = parent.sceneBoundingRect()
         self.childRect = child.sceneBoundingRect()
         # Activate cache mode to boost rendering by calling paint less often
         self.setCacheMode(QGraphicsItem.DeviceCoordinateCache)
-        # When the child moves, the connection may need to adjust the end point
+        # When the parent or child move, the connection may need
+        # to adjust the end point: done upon signal reception
         self.child.moved.connect(self.child_moved)
+        self.parent.moved.connect(self.parent_moved)
         # Syntax error indicator
         self.syntax_error: Boolean = False
+        # Flag to choose the bold pen when painting the edge if selected
+        self.selected = False
 
     @Slot(float, float)
     def child_moved(self, delta_x, delta_y):
         ''' When the connection child moves - redefine in subclasses '''
         pass
 
+    @Slot(float, float)
+    def parent_moved(self, delta_x, delta_y):
+        ''' When the connection parent moves - redefine in subclasses '''
+        self.parent.update_connections()
+
     @property
     def start_point(self):
         ''' Compute connection origin - redefine in subclasses '''
@@ -90,8 +101,14 @@ class Connection(QGraphicsPathItem):
                 QPointF(endp.x() + 5, endp.y() - 5))
 
     def select(self, selected=True):
-        ''' Select a connection - for future use? '''
-        return
+        ''' Select a connection - make it bold '''
+        if selected:
+            self.selected = True
+            self.setPen(self.bold_pen)
+        else:
+            self.selected = False
+            self.setPen(self.default_pen)
+        self.update()   # force a repaint
 
     def angle_arrow(self, path, origin='head'):
         ''' Compute the two points of the arrow head with the right angle '''
@@ -179,7 +196,7 @@ class JoinConnection(Connection):
         if self.parentItem().terminal_symbol:
             self.setPath(QPainterPath())
         else:
-            super(JoinConnection, self).reshape()
+            super().reshape()
 
     @property
     def start_point(self):
@@ -256,7 +273,7 @@ class SignalList(EditableText):
     ''' Simplified text editor for signal lists '''
     def __init__(self, parent, text='', hyperlink = None):
         ''' Smaller font than normal text '''
-        super(SignalList, self).__init__(parent, text)
+        super().__init__(parent, text)
         self.setFont(QFont('Ubuntu', pointSize=8))
 
     def set_text_alignment(self):
@@ -274,7 +291,7 @@ class SignalList(EditableText):
     # pylint: disable=C0103
     def focusOutEvent(self, event):
         ''' Redefined function - update in_sig and out_sig in parent '''
-        super(SignalList, self).focusOutEvent(event)
+        super().focusOutEvent(event)
 
 
 class Signalroute(Connection):
@@ -284,7 +301,7 @@ class Signalroute(Connection):
 
     def __init__(self, parent, child=None):
         ''' Set generic parameters from Connection class '''
-        super(Signalroute, self).__init__(parent, child or parent)
+        super().__init__(parent, child or parent)
         self.parser = ogParser
         self.blackbold = ()
         self.redbold = ()
@@ -347,7 +364,7 @@ class Signalroute(Connection):
 
     def reshape(self):
         ''' Redefine shape function to add the text areas '''
-        super(Signalroute, self).reshape()
+        super().reshape()
 
         width_in = self.label_in.boundingRect().width()
 
@@ -427,8 +444,36 @@ class Channel(Signalroute):
     @Slot(float, float)
     def child_moved(self, delta_x, delta_y):
         ''' When the connection child moves - redefined function '''
+        # compute the distance between the start and end points
+        dist_x = abs(self.end_point.x() - self.start_point.x())
+        dist_y = abs(self.end_point.y() - self.start_point.y())
+        new_dist_x = dist_x - delta_x
+        new_dist_y = dist_y - delta_y
+
         self._end_point.setX(self._end_point.x() - delta_x)
         self._end_point.setY(self._end_point.y() - delta_y)
+        x_shift, y_shift = [], []
+        middle_points = list(self.middle_points)
+
+        self._middle_points = []
+        for ratio, point in zip(self._ratios, middle_points):
+            fact_x, fact_y = ratio
+            sp = self.start_point
+            new_x = (sp.x() + new_dist_x * fact_x) if 0 <= fact_x <= 1 \
+                    else point.x() - delta_x
+            new_y = (sp.y() + new_dist_y * fact_y) if 0 <= fact_y <= 1 \
+                    else point.y() - delta_y
+            self._middle_points.append(
+                    self.parent.mapToScene(QPointF(new_x, new_y)))
+
+        self.reshape()
+        self.update() # force a repaint
+
+    @Slot(float, float)
+    def parent_moved(self, delta_x, delta_y):
+        ''' When the connection parent moves - redefined function '''
+        self.reshape()
+        self.update() # force a repaint
 
     @property
     def start_point(self):
@@ -458,6 +503,25 @@ class Channel(Signalroute):
 
     @middle_points.setter
     def middle_points(self, points_scene_coord):
+        ''' Redefined function: also store the relative position (percentage)
+            to the line length, in order to ensure proper dimensioning of
+            the connection when blocks are moved '''
+        # compute the distance between the start and end points
+        dist_x = abs(self.end_point.x() - self.start_point.x())
+        dist_y = abs(self.end_point.y() - self.start_point.y())
+        # Compute the distance ratio
+        self._ratios = []
+        for point in points_scene_coord:
+            pCoord = self.parent.mapFromScene(point)
+            len_x = abs(pCoord.x() - self.start_point.x())
+            len_y = abs(pCoord.y() - self.start_point.y())
+            fact_x = 1 if dist_x == 0 else len_x / dist_x
+            fact_y = 1 if dist_y == 0 else len_y / dist_y
+            if pCoord.y() < self.start_point.y():
+                fact_y = -fact_y
+            if pCoord.x() < self.start_point.x():
+                fact_x = -fact_x
+            self._ratios.append((fact_x, fact_y))
         self._middle_points = points_scene_coord
 
     def add_point(self, scene_coord):
@@ -466,7 +530,7 @@ class Channel(Signalroute):
     def paint(self, painter, _, ___):
         ''' Apply anti-aliasing '''
         painter.setRenderHint(QPainter.Antialiasing, True)
-        super(Channel, self).paint(painter, _, ___)
+        super().paint(painter, _, ___)
 
 
 
@@ -477,7 +541,7 @@ class Controlpoint(QGraphicsPathItem):
         ''' Set the original control point - with color, shape '''
         path = QPainterPath()
         path.addEllipse(pos.x() - 5, pos.y() - 5, 10, 10)
-        super(Controlpoint, self).__init__(path, parent=edge)
+        super().__init__(path, parent=edge)
         self.setPen(QColor(50, 100, 120, 200))
         self.setBrush(QColor(200, 200, 210, 120))
         self.setFlags(QGraphicsItem.ItemIsSelectable |
@@ -492,7 +556,7 @@ class Controlpoint(QGraphicsPathItem):
 
     def mouseMoveEvent(self, event):
         ''' When user moves a control point, update the connection shape '''
-        super(Controlpoint, self).mouseMoveEvent(event)
+        super().mouseMoveEvent(event)
         self.edge.reshape()
 
 
@@ -504,7 +568,7 @@ class Connectionpoint(Controlpoint):
     '''
     def __init__(self, pos, edge, symbol):
         ''' Create the point - as a small, lightblue box '''
-        super(Connectionpoint, self).__init__(pos, edge=edge)
+        super().__init__(pos, edge=edge)
         path = QPainterPath()
         path.addRect(0, 0, 10, 10)
         self.setPath(path)
@@ -538,7 +602,7 @@ class Connectionpoint(Controlpoint):
             where the actual connection point should be placed
         '''
         # calling super function moves to the new point
-        super(Connectionpoint, self).mouseMoveEvent(event)
+        super().mouseMoveEvent(event)
         # Then compute a valid position, based on the owning symbol
         self.update_position()
 
@@ -548,7 +612,7 @@ class Edge(Connection):
     def __init__(self, edge, graph):
         ''' Set generic parameters from Connection class '''
         self.text_label = None
-        super(Edge, self).__init__(edge['source'], edge['target'])
+        super().__init__(edge['source'], edge['target'])
         self.edge = edge
         self.graph = graph
         # Set connection points as not visible, by default
@@ -636,7 +700,8 @@ class Edge(Connection):
             metrics = QFontMetrics(font)
             label = self.edge.get('label', '') or ''
             lines = label.split('\n')
-            width = metrics.width(max(lines)) # longest line
+            longest_line = max(lines, key=len)
+            width = metrics.horizontalAdvance(longest_line)
             height = metrics.height() * len(lines)
             # lp is the position of the center of the text
             pos = self.mapFromScene(*self.edge['lp'])
@@ -670,7 +735,7 @@ class Edge(Connection):
     def paint(self, painter, option, widget):
         ''' Apply anti-aliasing to Edge Connections '''
         painter.setRenderHint(QPainter.Antialiasing, True)
-        super(Edge, self).paint(painter, option, widget)
+        super().paint(painter, option, widget)
         # Draw lines between connection points, if visible
         if self.bezier_visible:
             painter.setPen(
