@@ -191,7 +191,7 @@ class Primary(Expression):
 
     def trace(self):
         ''' Debug output for a primary '''
-        return u'PRIMARY : {exp} ({l},{c})'.format(exp=self.inputString,
+        return 'PRIMARY : {exp} ({l},{c})'.format(exp=self.inputString,
                 l=self.line, c=self.charPositionInLine)
 
 
@@ -321,14 +321,16 @@ class PrimSequence(Primary):
 class Decision:
     ''' AST Entry for a decision '''
     def __init__(self):
-        ''' A DECISION statement '''
-        self.inputString = ''
+        ''' A DECISION or ALTERNATIVE statement '''
+        self.inputString = 'true'
         self.line = None
         self.charPositionInLine = None
         self.pos_x, self.pos_y = None, None
         self.width = 70
         self.height = 50
-        # kind can be 'any', 'informal_text', or 'question'
+        # kind can be 'any', 'informal_text', 'question' or 'alternative'
+        # (alternative for the corresponding symbol, in which
+        # case the question has to be a ground expression)
         self.kind = None
         # question is an Expression
         self.question = None
@@ -336,6 +338,8 @@ class Decision:
         self.informalText = None
         # list of type Answer
         self.answers = []
+        # When kind is 'alternative', set the only Transition to keep
+        self.alternative = None
         # optional comment symbol
         self.comment = None
         # optional hyperlink
@@ -347,6 +351,9 @@ class Decision:
         # the path allows to retrieve the location of the symbol
         # in the hierarchy (PROCESS foo, PROCEDURE bar..). for Error handling.
         self.path = []
+        # Directive for the renderer to ignore the action in a transition
+        # (used if the symbol was added by the parser)
+        self.no_render = False
 
     def trace(self):
         ''' Debug output for a decision '''
@@ -370,7 +377,7 @@ class Answer:
         #      'closed_range'|'constant'|'open_range'|'else'|'informal_text'
         # and content is either strings (informal text)
         #           or set of two numbers (closed range)
-        #           or tuple (EprEq, constant) for constant
+        #           or tuple (ExprEq, constant) for constant
         #           or tuple (op, constant) for open_range
         #           or None ('else' branch)
         # with op being either ExprEq, ExprNeq, ExprGt, ExprGe, ExprLt, or ExprLe (types)
@@ -413,6 +420,9 @@ class Task:
         # the path allows to retrieve the location of the symbol
         # in the hierarchy (PROCESS foo, PROCEDURE bar..). for Error handling.
         self.path = []
+        # Directive for the renderer to ignore the action in a transition
+        # (used if the symbol was added by the parser)
+        self.no_render = False
 
     def trace(self):
         ''' Debug output for a task '''
@@ -449,7 +459,7 @@ class Output:
         self.height = 35
         self.line = None
         self.charPositionInLine = None
-        # list of {'outputName':ID, 'params':list of Expression, 'tmpVars':[]}
+        # list of {'outputName':ID, 'params':list of Expression, 'tmpVars':[], 'toDest': PID}
         self.output = []
         # optional comment symbol
         self.comment = None
@@ -460,6 +470,9 @@ class Output:
         # the path allows to retrieve the location of the symbol
         # in the hierarchy (PROCESS foo, PROCEDURE bar..). for Error handling.
         self.path = []
+        # Directive for the renderer to ignore the action in a transition
+        # (used if the symbol was added by the parser)
+        self.no_render = False
 
     def trace(self):
         ''' Debug output for an Output symbol '''
@@ -572,6 +585,9 @@ class Label:
         # the path allows to retrieve the location of the symbol
         # in the hierarchy (PROCESS foo, PROCEDURE bar..). for Error handling.
         self.path = []
+        # Directive for the renderer to ignore the action in a transition
+        # (used if the symbol was added by the parser)
+        self.no_render = False
 
     def trace(self):
         ''' Debug output for a label '''
@@ -631,7 +647,7 @@ class Input:
     def __init__(self):
         ''' Initialize the Input attributes '''
         # inputString is the user text, it can contain several inputs
-        self.inputString = ''
+        self.inputString = 'foo'
         self.pos_x, self.pos_y = None, None
         self.width = 70
         self.height = 35
@@ -822,7 +838,7 @@ class TextArea:
     ''' AST Entry for text areas (containing declarations/comments) '''
     def __init__(self):
         ''' Text area (raw content for rendering only) '''
-        self.inputString = '-- Text area for declarations and comments\n\n'
+        self.inputString = '-- Text area for declarations and comments'
         self.line = None
         self.charPositionInLine = None
         # Set default coordinates and width/height
@@ -1211,7 +1227,7 @@ class AST:
         self.asn1Modules = None
         # DV is the Asn1scc imported module
         self.DV = None
-        # ASN.1-defined constants (constants in Ada but variables in C)
+        # ASN.1-defined constants
         # dictionary: {ConstantName: type } - copied from dataview.py
         self.asn1_constants = {}
 
